@@ -6,7 +6,7 @@ mod fixtures;
 
 use criterion::{criterion_group, criterion_main, Criterion};
 
-use icu_datetime::pattern::Pattern;
+use icu_datetime::pattern::reference::Pattern;
 
 fn pattern_benches(c: &mut Criterion) {
     let patterns: Vec<String> = fixtures::get_patterns_fixture().unwrap().0;
@@ -17,7 +17,7 @@ fn pattern_benches(c: &mut Criterion) {
         group.bench_function("parse", |b| {
             b.iter(|| {
                 for input in &patterns {
-                    let _ = Pattern::from_bytes(input).unwrap();
+                    let _ = input.parse::<Pattern>().unwrap();
                 }
             })
         });
