@@ -44,18 +44,13 @@
 //! use icu::datetime::DateTimeFormatOptions;
 //! use icu::datetime::options::components;
 //!
-//! let bag = components::Bag {
-//!     year: Some(components::Year::Numeric),
-//!     month: Some(components::Month::Long),
-//!     day: Some(components::Numeric::Numeric),
+//! let mut bag = components::Bag::default();
+//! bag.year = Some(components::Year::Numeric);
+//! bag.month = Some(components::Month::Long);
+//! bag.day = Some(components::Day::NumericDayOfMonth);
 //!
-//!     hour: Some(components::Numeric::TwoDigit),
-//!     minute: Some(components::Numeric::TwoDigit),
-//!
-//!     preferences: None,
-//!
-//!     ..Default::default()
-//! };
+//! bag.hour = Some(components::Numeric::TwoDigit);
+//! bag.minute = Some(components::Numeric::TwoDigit);
 //!
 //! // The options can be created manually.
 //! let options = DateTimeFormatOptions::Components(bag);
@@ -86,6 +81,7 @@ use serde::{Deserialize, Serialize};
 /// See the [module-level](./index.html) docs for more information.
 #[derive(Debug, Clone, PartialEq, Default, Copy)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+#[non_exhaustive]
 pub struct Bag {
     /// Include the era, such as "AD" or "CE".
     pub era: Option<Text>,
@@ -93,12 +89,10 @@ pub struct Bag {
     pub year: Option<Year>,
     /// Include the month, such as "April" or "Apr".
     pub month: Option<Month>,
-    /// Include the week, such as "1st" or "1".
-    #[doc(hidden)]
-    // TODO(#488): make visible once fully supported.
+    /// Include the week number, such as "51st" or "51" for week 51.
     pub week: Option<Week>,
-    /// Include the day, such as "07" or "7".
-    pub day: Option<Numeric>,
+    /// Include the day of the month/year, such as "07" or "7".
+    pub day: Option<Day>,
     /// Include the weekday, such as "Wednesday" or "Wed".
     pub weekday: Option<Text>,
 
@@ -117,6 +111,13 @@ pub struct Bag {
 }
 
 impl Bag {
+    /// Creates an empty components bag
+    ///
+    /// Has the same behavior as the [`Default`] implementation on this type.
+    pub fn empty() -> Self {
+        Self::default()
+    }
+
     #[allow(clippy::wrong_self_convention)]
     /// Converts the components::Bag into a Vec<Field>. The fields will be ordered in from most
     /// significant field to least significant. This is the order the fields are listed in
@@ -200,18 +201,20 @@ impl Bag {
         }
 
         if let Some(day) = self.day {
-            // TODO(#591,#592) Unimplemented day fields:
+            // TODO(#591) Unimplemented day fields:
             // D - Day of year
-            // F - Day of week in month
             // g - Modified Julian day.
             fields.push(Field {
-                symbol: FieldSymbol::Day(fields::Day::DayOfMonth),
+                symbol: FieldSymbol::Day(match day {
+                    Day::NumericDayOfMonth | Day::TwoDigitDayOfMonth => fields::Day::DayOfMonth,
+                    Day::DayOfWeekInMonth => fields::Day::DayOfWeekInMonth,
+                }),
                 length: match day {
-                    // Day of month (numeric).
-                    // d    1 	  Numeric: minimum digits
-                    // dd   01 	  Numeric: 2 digits, zero pad if needed
-                    Numeric::Numeric => FieldLength::One,
-                    Numeric::TwoDigit => FieldLength::TwoDigit,
+                    // d    1 	  Numeric day of month: minimum digits
+                    // dd   01 	  Numeric day of month: 2 digits, zero pad if needed
+                    // F    1  	  Numeric day of week in month: minimum digits
+                    Day::NumericDayOfMonth | Day::DayOfWeekInMonth => FieldLength::One,
+                    Day::TwoDigitDayOfMonth => FieldLength::TwoDigit,
                 },
             });
         }
@@ -319,7 +322,13 @@ impl Bag {
         }
 
         debug_assert!(
-            fields.windows(2).all(|f| f[0] < f[1]),
+            fields.windows(2).all(|f| {
+                #[allow(clippy::indexing_slicing)]
+                // TODO(#1668) Clippy exceptions need docs or fixing.
+                // Change to code redired as clippy on statements arex experimental
+                let comp = f[0] < f[1];
+                comp
+            }),
             "The fields are sorted and unique."
         );
 
@@ -335,6 +344,7 @@ impl Bag {
     derive(Serialize, Deserialize),
     serde(rename_all = "kebab-case")
 )]
+#[non_exhaustive]
 pub enum Numeric {
     /// Display the numeric value. For instance in a year this would be "1970".
     Numeric,
@@ -349,6 +359,7 @@ pub enum Numeric {
     derive(Serialize, Deserialize),
     serde(rename_all = "kebab-case")
 )]
+#[non_exhaustive]
 pub enum Text {
     /// Display the long form of the text, such as "Wednesday" for the weekday.
     Long,
@@ -365,6 +376,7 @@ pub enum Text {
     derive(Serialize, Deserialize),
     serde(rename_all = "kebab-case")
 )]
+#[non_exhaustive]
 pub enum Year {
     /// The numeric value of the year, such as "2018" for 2018-12-31.
     Numeric,
@@ -385,12 +397,13 @@ pub enum Year {
     derive(Serialize, Deserialize),
     serde(rename_all = "kebab-case")
 )]
+#[non_exhaustive]
 pub enum Month {
     /// The numeric value of the month, such as "4".
     Numeric,
     /// The two-digit value of the month, such as "04".
     TwoDigit,
-    /// The two-digit value of the month, such as "April".
+    /// The long value of the month, such as "April".
     Long,
     /// The short value of the month, such as "Apr".
     Short,
@@ -400,25 +413,43 @@ pub enum Month {
 
 // Each enum variant is documented with the UTS 35 field information from:
 // https://unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table
-//
-/// Options for displaying the current week for the `components::`[`Bag`].
-#[doc(hidden)]
-// TODO(#488): make visible once fully supported.
+
+/// Options for displaying the current week number for the `components::`[`Bag`].
+///
+/// Week numbers are relative to either a month or year, e.g. 'week 3 of January' or 'week 40 of 2000'.
 #[derive(Debug, Clone, Copy, PartialEq)]
 #[cfg_attr(
     feature = "serde",
     derive(Serialize, Deserialize),
     serde(rename_all = "kebab-case")
 )]
+#[non_exhaustive]
 pub enum Week {
-    /// The week of the month, such as "3".
+    /// The week of the month, such as the "3" in "week 3 of January".
     WeekOfMonth,
-    /// The numeric value of the week of the year, such as "8".
+    /// The numeric value of the week of the year, such as the "8" in "week 8 of 2000".
     NumericWeekOfYear,
-    /// The two-digit value of the week of the year, such as "08".
+    /// The two-digit value of the week of the year, such as the "08" in "2000-W08".
     TwoDigitWeekOfYear,
 }
 
+/// Options for displaying the current day of the month or year.
+#[derive(Debug, Clone, PartialEq, Copy)]
+#[cfg_attr(
+    feature = "serde",
+    derive(Serialize, Deserialize),
+    serde(rename_all = "kebab-case")
+)]
+#[non_exhaustive]
+pub enum Day {
+    /// The numeric value of the day of month, such as the "2" in July 2 1984.
+    NumericDayOfMonth,
+    /// The two digit value of the day of month, such as the "02" in 1984-07-02.
+    TwoDigitDayOfMonth,
+    /// The day of week in this month, such as the "2" in 2nd Wednesday of July.
+    DayOfWeekInMonth,
+}
+
 /// Options for displaying a time zone for the `components::`[`Bag`].
 ///
 /// Note that the initial implementation is focusing on only supporting ECMA-402 compatible
@@ -429,6 +460,7 @@ pub enum Week {
     derive(Serialize, Deserialize),
     serde(rename_all = "kebab-case")
 )]
+#[non_exhaustive]
 pub enum TimeZoneName {
     // UTS-35 fields: z..zzz
     //
@@ -517,7 +549,9 @@ impl<'data> From<&PatternPlurals<'data>> for Bag {
                             Text::Short
                         }
                         FieldLength::Wide => Text::Long,
-                        FieldLength::Narrow | FieldLength::Six => Text::Narrow,
+                        FieldLength::Narrow | FieldLength::Six | FieldLength::Fixed(_) => {
+                            Text::Narrow
+                        }
                     });
                 }
                 FieldSymbol::Year(year) => {
@@ -540,7 +574,9 @@ impl<'data> From<&PatternPlurals<'data>> for Bag {
                         FieldLength::TwoDigit => Month::TwoDigit,
                         FieldLength::Abbreviated => Month::Short,
                         FieldLength::Wide => Month::Long,
-                        FieldLength::Narrow | FieldLength::Six => Month::Narrow,
+                        FieldLength::Narrow | FieldLength::Six | FieldLength::Fixed(_) => {
+                            Month::Narrow
+                        }
                     });
                 }
                 FieldSymbol::Week(week) => {
@@ -555,13 +591,11 @@ impl<'data> From<&PatternPlurals<'data>> for Bag {
                 FieldSymbol::Day(day) => {
                     bag.day = Some(match day {
                         fields::Day::DayOfMonth => match field.length {
-                            FieldLength::TwoDigit => Numeric::TwoDigit,
-                            _ => Numeric::Numeric,
+                            FieldLength::TwoDigit => Day::TwoDigitDayOfMonth,
+                            _ => Day::NumericDayOfMonth,
                         },
                         fields::Day::DayOfYear => unimplemented!("fields::Day::DayOfYear #591"),
-                        fields::Day::DayOfWeekInMonth => {
-                            unimplemented!("fields::Day::DayOfWeekInMonth #592")
-                        }
+                        fields::Day::DayOfWeekInMonth => Day::DayOfWeekInMonth,
                         fields::Day::ModifiedJulianDay => {
                             unimplemented!("fields::Day::ModifiedJulianDay")
                         }
@@ -603,7 +637,9 @@ impl<'data> From<&PatternPlurals<'data>> for Bag {
                             }
                             FieldLength::Abbreviated => Text::Short,
                             FieldLength::Wide => Text::Long,
-                            FieldLength::Narrow | FieldLength::Six => Text::Narrow,
+                            FieldLength::Narrow | FieldLength::Six | FieldLength::Fixed(_) => {
+                                Text::Narrow
+                            }
                         },
                         fields::Weekday::Local => unimplemented!("fields::Weekday::Local"),
                     });
@@ -683,7 +719,7 @@ mod test {
             year: Some(Year::Numeric),
             month: Some(Month::Long),
             week: Some(Week::WeekOfMonth),
-            day: Some(Numeric::Numeric),
+            day: Some(Day::NumericDayOfMonth),
 
             hour: Some(Numeric::Numeric),
             minute: Some(Numeric::Numeric),
@@ -710,7 +746,7 @@ mod test {
         let bag = Bag {
             year: Some(Year::Numeric),
             month: Some(Month::TwoDigit),
-            day: Some(Numeric::Numeric),
+            day: Some(Day::NumericDayOfMonth),
             ..Default::default()
         };
         assert_eq!(
