@@ -2,6 +2,7 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
+use alloc::vec;
 use alloc::vec::Vec;
 use core::cmp::Ordering;
 
@@ -229,6 +230,8 @@ pub fn create_best_pattern_for_fields<'data>(
             date_patterns.for_each_mut(|pattern| {
                 let date = pattern.clone();
                 let time = time_pattern.clone();
+                #[allow(clippy::expect_used)]
+                // TODO(#1668) Clippy exceptions need docs or fixing.
                 let dt = dt_pattern
                     .clone()
                     .combined(date, time)
@@ -368,13 +371,13 @@ pub fn get_best_available_format_pattern<'data>(
                         .symbol
                         .discriminant_cmp(&requested_field.symbol)
                     {
-                        Ordering::Greater => {
+                        Ordering::Less => {
                             // Keep searching for a matching skeleton field.
                             skeleton_fields.next();
                             distance += SKELETON_EXTRA_SYMBOL;
                             continue;
                         }
-                        Ordering::Less => {
+                        Ordering::Greater => {
                             // The requested field symbol is missing from the skeleton.
                             distance += REQUESTED_SYMBOL_MISSING;
                             missing_fields += 1;
@@ -422,6 +425,17 @@ pub fn get_best_available_format_pattern<'data>(
         }
     }
 
+    if !prefer_matched_pattern && closest_distance >= TEXT_VS_NUMERIC_DISTANCE {
+        if let [field] = fields {
+            // A single field was requested and the best pattern either includes extra fields or can't be adjusted to match
+            // (e.g. text vs numeric). We return the field instead of the matched pattern.
+            return BestSkeleton::AllFieldsMatch(
+                Pattern::from(vec![PatternItem::Field(*field)]).into(),
+            );
+        }
+    }
+
+    #[allow(clippy::expect_used)] // TODO(#1668) Clippy exceptions need docs or fixing.
     let mut closest_format_pattern = closest_format_pattern
         .expect("At least one closest format pattern will always be found.")
         .clone();
@@ -435,8 +449,9 @@ pub fn get_best_available_format_pattern<'data>(
     }
 
     // Modify the resulting pattern to have fields of the same length.
+    #[allow(clippy::panic)] // TODO(#1668) Clippy exceptions need docs or fixing.
     if prefer_matched_pattern {
-        #[cfg(not(feature = "provider_transform_internals"))]
+        #[cfg(not(feature = "datagen"))]
         panic!("This code branch should only be run when transforming provider code.");
     } else {
         closest_format_pattern.for_each_mut(|pattern| {
