@@ -7,22 +7,26 @@
 mod fixtures;
 mod patterns;
 
-use icu_calendar::{buddhist::Buddhist, japanese::Japanese, AsCalendar, DateTime, Gregorian};
+use icu_calendar::{
+    buddhist::Buddhist, coptic::Coptic, indian::Indian, japanese::Japanese, AsCalendar, DateTime,
+    Gregorian,
+};
+use icu_datetime::provider::time_zones::{MetaZoneId, TimeZoneBcp47Id};
 use icu_datetime::{
     mock::{parse_gregorian_from_str, zoned_datetime::MockZonedDateTime},
     pattern::runtime::Pattern,
     provider::{
         calendar::{DatePatternsV1Marker, DateSkeletonPatternsV1Marker, DateSymbolsV1Marker},
-        key::{DATE_PATTERNS_V1, DATE_SKELETON_PATTERNS_V1, DATE_SYMBOLS_V1},
+        week_data::WeekDataV1Marker,
     },
-    time_zone::TimeZoneFormat,
+    time_zone::{TimeZoneFormat, TimeZoneFormatOptions},
     CldrCalendar, DateTimeFormat, DateTimeFormatOptions, ZonedDateTimeFormat,
 };
-use icu_locid::{LanguageIdentifier, Locale};
-use icu_plurals::provider::PluralRulesV1Marker;
-use icu_provider::fork::by_key::MultiForkByKeyProvider;
+use icu_locid::{unicode_ext_key, unicode_ext_value, LanguageIdentifier, Locale};
+use icu_plurals::provider::OrdinalV1Marker;
 use icu_provider::prelude::*;
-use icu_provider::struct_provider::AnyPayloadProvider;
+use icu_provider_adapters::fork::by_key::MultiForkByKeyProvider;
+use icu_provider_adapters::struct_provider::AnyPayloadProvider;
 use patterns::{
     get_dayperiod_tests, get_time_zone_tests,
     structs::{
@@ -31,7 +35,7 @@ use patterns::{
     },
 };
 use std::fmt::Write;
-use tinystr::tinystr8;
+use tinystr::tinystr;
 
 fn test_fixture(fixture_name: &str) {
     let provider = icu_testdata::get_provider();
@@ -45,6 +49,8 @@ fn test_fixture(fixture_name: &str) {
         let input_value = parse_gregorian_from_str(&fx.input.value).unwrap();
         let input_buddhist = input_value.to_calendar(Buddhist);
         let input_japanese = input_value.to_calendar(japanese);
+        let input_coptic = input_value.to_calendar(Coptic);
+        let input_indian = input_value.to_calendar(Indian);
 
         let description = match fx.description {
             Some(description) => {
@@ -74,6 +80,24 @@ fn test_fixture(fixture_name: &str) {
                     &options,
                     &description,
                 )
+            } else if let Some(locale) = locale.strip_prefix("coptic/") {
+                assert_fixture_element(
+                    locale,
+                    &input_coptic,
+                    &output_value,
+                    &provider,
+                    &options,
+                    &description,
+                )
+            } else if let Some(locale) = locale.strip_prefix("indian/") {
+                assert_fixture_element(
+                    locale,
+                    &input_indian,
+                    &output_value,
+                    &provider,
+                    &options,
+                    &description,
+                )
             } else {
                 assert_fixture_element(
                     &locale,
@@ -98,10 +122,11 @@ fn assert_fixture_element<A, D>(
 ) where
     A: AsCalendar,
     A::Calendar: CldrCalendar,
-    D: DataProvider<DateSymbolsV1Marker>
-        + DataProvider<DatePatternsV1Marker>
-        + DataProvider<DateSkeletonPatternsV1Marker>
-        + DataProvider<PluralRulesV1Marker>,
+    D: ResourceProvider<DateSymbolsV1Marker>
+        + ResourceProvider<DatePatternsV1Marker>
+        + ResourceProvider<DateSkeletonPatternsV1Marker>
+        + ResourceProvider<OrdinalV1Marker>
+        + ResourceProvider<WeekDataV1Marker>,
 {
     let locale: Locale = locale.parse().unwrap();
     let dtf = DateTimeFormat::<A::Calendar>::try_new(locale, provider, options).unwrap();
@@ -132,8 +157,8 @@ fn test_fixture_with_time_zones(fixture_name: &str, config: TimeZoneConfig) {
         let options = fixtures::get_options(&fx.input.options);
 
         let mut input_value: MockZonedDateTime = fx.input.value.parse().unwrap();
-        input_value.time_zone.time_zone_id = config.time_zone_id.clone();
-        input_value.time_zone.metazone_id = config.metazone_id.clone();
+        input_value.time_zone.time_zone_id = config.time_zone_id.map(TimeZoneBcp47Id);
+        input_value.time_zone.metazone_id = config.metazone_id.map(MetaZoneId);
         input_value.time_zone.time_variant = config.time_variant;
 
         let description = match fx.description {
@@ -148,7 +173,12 @@ fn test_fixture_with_time_zones(fixture_name: &str, config: TimeZoneConfig) {
         for (locale, output_value) in fx.output.values.into_iter() {
             let locale: Locale = locale.parse().unwrap();
             let dtf = ZonedDateTimeFormat::<Gregorian>::try_new(
-                locale, &provider, &provider, &provider, &options,
+                locale,
+                &provider,
+                &provider,
+                &provider,
+                &options,
+                &TimeZoneFormatOptions::default(),
             )
             .unwrap();
             let result = dtf.format_to_string(&input_value);
@@ -175,16 +205,16 @@ fn test_dayperiod_patterns() {
     let provider = icu_testdata::get_provider();
     let format_options = DateTimeFormatOptions::default();
     for test in get_dayperiod_tests("dayperiods").unwrap().0 {
-        let langid: LanguageIdentifier = test.locale.parse().unwrap();
+        let mut locale: Locale = test.locale.parse().unwrap();
+        locale
+            .extensions
+            .unicode
+            .keywords
+            .set(unicode_ext_key!("ca"), unicode_ext_value!("gregory"));
         let mut patterns_data: DataPayload<DatePatternsV1Marker> = provider
-            .load_payload(&DataRequest {
-                resource_path: ResourcePath {
-                    key: DATE_PATTERNS_V1,
-                    options: ResourceOptions {
-                        variant: Some("gregory".into()),
-                        langid: Some(langid.clone()),
-                    },
-                },
+            .load_resource(&DataRequest {
+                options: ResourceOptions::from(&locale),
+                metadata: Default::default(),
             })
             .unwrap()
             .take_payload()
@@ -193,27 +223,25 @@ fn test_dayperiod_patterns() {
             data.length_combinations.long = "{0}".parse().unwrap();
         });
         let symbols_data: DataPayload<DateSymbolsV1Marker> = provider
-            .load_payload(&DataRequest {
-                resource_path: ResourcePath {
-                    key: DATE_SYMBOLS_V1,
-                    options: ResourceOptions {
-                        variant: Some("gregory".into()),
-                        langid: Some(langid.clone()),
-                    },
-                },
+            .load_resource(&DataRequest {
+                options: ResourceOptions::from(&locale),
+                metadata: Default::default(),
             })
             .unwrap()
             .take_payload()
             .unwrap();
         let skeleton_data: DataPayload<DateSkeletonPatternsV1Marker> = provider
-            .load_payload(&DataRequest {
-                resource_path: ResourcePath {
-                    key: DATE_SKELETON_PATTERNS_V1,
-                    options: ResourceOptions {
-                        variant: Some("gregory".into()),
-                        langid: Some(langid.clone()),
-                    },
-                },
+            .load_resource(&DataRequest {
+                options: ResourceOptions::from(&locale),
+                metadata: Default::default(),
+            })
+            .unwrap()
+            .take_payload()
+            .unwrap();
+        let week_data: DataPayload<WeekDataV1Marker> = provider
+            .load_resource(&DataRequest {
+                options: ResourceOptions::temp_for_region(locale.id.region),
+                metadata: Default::default(),
             })
             .unwrap()
             .take_payload()
@@ -232,21 +260,25 @@ fn test_dayperiod_patterns() {
                         let local_provider = MultiForkByKeyProvider {
                             providers: vec![
                                 AnyPayloadProvider {
-                                    key: DATE_SYMBOLS_V1,
+                                    key: DateSymbolsV1Marker::KEY,
                                     data: symbols_data.clone().wrap_into_any_payload(),
                                 },
                                 AnyPayloadProvider {
-                                    key: DATE_SKELETON_PATTERNS_V1,
+                                    key: DateSkeletonPatternsV1Marker::KEY,
                                     data: skeleton_data.clone().wrap_into_any_payload(),
                                 },
                                 AnyPayloadProvider {
-                                    key: DATE_PATTERNS_V1,
+                                    key: DatePatternsV1Marker::KEY,
                                     data: patterns_data.clone().wrap_into_any_payload(),
                                 },
+                                AnyPayloadProvider {
+                                    key: WeekDataV1Marker::KEY,
+                                    data: week_data.clone().wrap_into_any_payload(),
+                                },
                             ],
                         };
                         let dtf = DateTimeFormat::<Gregorian>::try_new(
-                            langid.clone(),
+                            locale.clone(),
                             &local_provider.as_downcasting(),
                             &format_options,
                         )
@@ -258,7 +290,7 @@ fn test_dayperiod_patterns() {
                             locale:   `{}`,\n\
                             datetime: `{}`,\n\
                             pattern:  `{}`",
-                            langid,
+                            locale,
                             dt_input,
                             pattern_input,
                         );
@@ -277,36 +309,42 @@ fn test_time_zone_format_configs() {
         let langid: LanguageIdentifier = test.locale.parse().unwrap();
         let mut config = test.config;
         let mut datetime: MockZonedDateTime = test.datetime.parse().unwrap();
-        datetime.time_zone.time_zone_id = config.time_zone_id.take();
-        datetime.time_zone.metazone_id = config.metazone_id.take();
+        datetime.time_zone.time_zone_id = config.time_zone_id.take().map(TimeZoneBcp47Id);
+        datetime.time_zone.metazone_id = config.metazone_id.take().map(MetaZoneId);
         datetime.time_zone.time_variant = config.time_variant.take();
         for TimeZoneExpectation {
             patterns: _,
             configs,
+            fallback_formats,
             expected,
         } in &test.expectations
         {
             for &config_input in configs {
-                let tzf = TimeZoneFormat::try_from_config(
-                    langid.clone(),
-                    config_input.into(),
-                    &zone_provider,
-                )
-                .unwrap();
-                let mut buffer = String::new();
-                tzf.format_to_write(&mut buffer, &datetime).unwrap();
-                assert_eq!(
-                    buffer.to_string(),
-                    *expected,
-                    "\n\
+                for (&fallback_format, expect) in fallback_formats.iter().zip(expected.iter()) {
+                    let tzf = TimeZoneFormat::try_from_config(
+                        langid.clone(),
+                        config_input.into(),
+                        &zone_provider,
+                        &fallback_format.into(),
+                    )
+                    .unwrap();
+                    let mut buffer = String::new();
+                    tzf.format_to_write(&mut buffer, &datetime).unwrap();
+                    assert_eq!(
+                        buffer.to_string(),
+                        *expect,
+                        "\n\
                     locale:   `{}`,\n\
                     datetime: `{}`,\n\
                     config: `{:?}`,\n\
+                    fallback: `{:?}`\n
                     ",
-                    langid,
-                    test.datetime,
-                    config_input
-                );
+                        langid,
+                        test.datetime,
+                        config_input,
+                        fallback_format
+                    );
+                }
             }
         }
     }
@@ -320,48 +358,46 @@ fn test_time_zone_patterns() {
     let format_options = DateTimeFormatOptions::default();
 
     for test in get_time_zone_tests("time_zones").unwrap().0 {
-        let langid: LanguageIdentifier = test.locale.parse().unwrap();
+        let mut locale: Locale = test.locale.parse().unwrap();
+        locale
+            .extensions
+            .unicode
+            .keywords
+            .set(unicode_ext_key!("ca"), unicode_ext_value!("gregory"));
         let mut config = test.config;
         let mut datetime: MockZonedDateTime = test.datetime.parse().unwrap();
-        datetime.time_zone.time_zone_id = config.time_zone_id.take();
-        datetime.time_zone.metazone_id = config.metazone_id.take();
+        datetime.time_zone.time_zone_id = config.time_zone_id.take().map(TimeZoneBcp47Id);
+        datetime.time_zone.metazone_id = config.metazone_id.take().map(MetaZoneId);
         datetime.time_zone.time_variant = config.time_variant.take();
 
         let mut patterns_data: DataPayload<DatePatternsV1Marker> = date_provider
-            .load_payload(&DataRequest {
-                resource_path: ResourcePath {
-                    key: DATE_PATTERNS_V1,
-                    options: ResourceOptions {
-                        variant: Some("gregory".into()),
-                        langid: Some(langid.clone()),
-                    },
-                },
+            .load_resource(&DataRequest {
+                options: ResourceOptions::from(&locale),
+                metadata: Default::default(),
             })
             .unwrap()
             .take_payload()
             .unwrap();
         let skeleton_data: DataPayload<DateSkeletonPatternsV1Marker> = date_provider
-            .load_payload(&DataRequest {
-                resource_path: ResourcePath {
-                    key: DATE_SKELETON_PATTERNS_V1,
-                    options: ResourceOptions {
-                        variant: Some("gregory".into()),
-                        langid: Some(langid.clone()),
-                    },
-                },
+            .load_resource(&DataRequest {
+                options: ResourceOptions::from(&locale),
+                metadata: Default::default(),
             })
             .unwrap()
             .take_payload()
             .unwrap();
         let symbols_data: DataPayload<DateSymbolsV1Marker> = date_provider
-            .load_payload(&DataRequest {
-                resource_path: ResourcePath {
-                    key: DATE_SYMBOLS_V1,
-                    options: ResourceOptions {
-                        variant: Some("gregory".into()),
-                        langid: Some(langid.clone()),
-                    },
-                },
+            .load_resource(&DataRequest {
+                options: ResourceOptions::from(&locale),
+                metadata: Default::default(),
+            })
+            .unwrap()
+            .take_payload()
+            .unwrap();
+        let week_data: DataPayload<WeekDataV1Marker> = date_provider
+            .load_resource(&DataRequest {
+                options: ResourceOptions::temp_for_region(locale.id.region),
+                metadata: Default::default(),
             })
             .unwrap()
             .take_payload()
@@ -374,6 +410,7 @@ fn test_time_zone_patterns() {
         for TimeZoneExpectation {
             patterns,
             configs: _,
+            fallback_formats,
             expected,
         } in &test.expectations
         {
@@ -387,40 +424,49 @@ fn test_time_zone_patterns() {
                 let local_provider = MultiForkByKeyProvider {
                     providers: vec![
                         AnyPayloadProvider {
-                            key: DATE_SYMBOLS_V1,
+                            key: DateSymbolsV1Marker::KEY,
                             data: symbols_data.clone().wrap_into_any_payload(),
                         },
                         AnyPayloadProvider {
-                            key: DATE_SKELETON_PATTERNS_V1,
+                            key: DateSkeletonPatternsV1Marker::KEY,
                             data: skeleton_data.clone().wrap_into_any_payload(),
                         },
                         AnyPayloadProvider {
-                            key: DATE_PATTERNS_V1,
+                            key: DatePatternsV1Marker::KEY,
                             data: patterns_data.clone().wrap_into_any_payload(),
                         },
+                        AnyPayloadProvider {
+                            key: WeekDataV1Marker::KEY,
+                            data: week_data.clone().wrap_into_any_payload(),
+                        },
                     ],
                 };
 
-                let dtf = ZonedDateTimeFormat::<Gregorian>::try_new(
-                    langid.clone(),
-                    &local_provider.as_downcasting(),
-                    &zone_provider,
-                    &plural_provider,
-                    &format_options,
-                )
-                .unwrap();
+                for (&fallback_format, expect) in fallback_formats.iter().zip(expected.iter()) {
+                    let dtf = ZonedDateTimeFormat::<Gregorian>::try_new(
+                        locale.clone(),
+                        &local_provider.as_downcasting(),
+                        &zone_provider,
+                        &plural_provider,
+                        &format_options,
+                        &fallback_format.into(),
+                    )
+                    .unwrap();
 
-                assert_eq!(
-                    dtf.format(&datetime).to_string(),
-                    *expected,
-                    "\n\
+                    assert_eq!(
+                        dtf.format(&datetime).to_string(),
+                        *expect,
+                        "\n\
                     locale:   `{}`,\n\
                     datetime: `{}`,\n\
-                    pattern:  `{}`",
-                    langid,
-                    test.datetime,
-                    pattern_input,
-                );
+                    pattern:  `{}`\n
+                    fallback: `{:?}`\n",
+                        locale,
+                        test.datetime,
+                        pattern_input,
+                        fallback_format,
+                    );
+                }
             }
         }
     }
@@ -434,8 +480,8 @@ fn test_length_fixtures() {
     test_fixture_with_time_zones(
         "lengths_with_zones_from_pdt",
         TimeZoneConfig {
-            metazone_id: Some(String::from("America_Pacific")),
-            time_variant: Some(tinystr8!("daylight")),
+            metazone_id: Some(tinystr!(4, "ampa")),
+            time_variant: Some(tinystr!(8, "daylight")),
             ..TimeZoneConfig::default()
         },
     );
@@ -501,49 +547,20 @@ fn test_components_combine_datetime() {
     test_fixture("components-combine-datetime");
 }
 
-#[test]
-fn constructing_datetime_format_with_missing_pattern_is_err() {
-    use icu_datetime::{
-        options::components::{Bag, Week},
-        DateTimeFormatError, DateTimeFormatOptions,
-    };
-    use icu_locid::Locale;
-    use icu_locid_macros::langid;
-
-    let options = DateTimeFormatOptions::Components(Bag {
-        // There's no pattern for just 'w'.
-        week: Some(Week::NumericWeekOfYear),
-        ..Default::default()
-    });
-
-    let locale: Locale = langid!("en").into();
-    let provider = icu_testdata::get_provider();
-    let result = DateTimeFormat::<Gregorian>::try_new(locale, &provider, &options);
-
-    assert!(matches!(
-        result.err(),
-        Some(DateTimeFormatError::UnsupportedOptions)
-    ));
-}
-
 #[test]
 fn constructing_datetime_format_with_time_zone_pattern_symbols_is_err() {
     use icu_datetime::{
         options::length::{Bag, Time},
         DateTimeFormatOptions,
     };
-    use icu_locid::Locale;
-    use icu_locid_macros::langid;
+    use icu_locid::locale;
 
-    let options = DateTimeFormatOptions::Length(Bag {
-        // Full has time-zone symbols.
-        time: Some(Time::Full),
-        ..Default::default()
-    });
+    let mut length_bag = Bag::default();
+    length_bag.time = Some(Time::Full); // Full has timezone symbols
+    let options = DateTimeFormatOptions::Length(length_bag);
 
-    let locale: Locale = langid!("en").into();
     let provider = icu_testdata::get_provider();
-    let result = DateTimeFormat::<Gregorian>::try_new(locale, &provider, &options);
+    let result = DateTimeFormat::<Gregorian>::try_new(locale!("en"), &provider, &options);
 
     assert!(result.is_err());
 }
