@@ -2,7 +2,7 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-#![cfg(all(test, feature = "provider_serde"))]
+#![cfg(all(test, feature = "datagen"))]
 
 use icu_datetime::pattern::reference::Pattern;
 use std::{fs::File, io::BufReader};
@@ -20,7 +20,7 @@ struct PatternFixtures {
 }
 
 fn get_pattern_fixtures() -> PatternFixtures {
-    let file = File::open("./tests/fixtures/tests/patterns.json".to_string())
+    let file = File::open("./tests/fixtures/tests/patterns.json")
         .expect("Unable to open ./tests/fixtures/tests/patterns.json");
     let reader = BufReader::new(file);
     serde_json::from_reader(reader).expect("Unable to deserialize pattern fixtures.")
