@@ -2,7 +2,7 @@
 // called LICENSE at the top level of the ICU4X source tree
 // (online at: https://github.com/unicode-org/icu4x/blob/main/LICENSE ).
 
-#![cfg(all(test, feature = "provider_serde"))]
+#![cfg(all(test, feature = "datagen"))]
 
 use icu_datetime::skeleton::reference::Skeleton;
 use std::{fs::File, io::BufReader};
@@ -16,7 +16,7 @@ struct SkeletonFixtures {
 }
 
 fn get_skeleton_fixtures() -> Vec<String> {
-    let file = File::open("./tests/fixtures/tests/skeletons.json".to_string())
+    let file = File::open("./tests/fixtures/tests/skeletons.json")
         .expect("Unable to open ./tests/fixtures/tests/skeletons.json");
     let reader = BufReader::new(file);
     let fixtures: SkeletonFixtures =
